@@ -74,10 +74,11 @@ class NooLite:
         Max level is 120
         First channal is 0 """
         self._cmd = self._init_command
-        self._cmd[1] = 0x06       # "Turn power on" command
+        self._cmd[1] = 0x06       # "set" command
         if self._set_ch(ch):
             return -2
         self._cmd[2] = 0x01       # send level
+        self._cmd[5] = level
         return self._send()
 
         # level in cmd must be in [0, 35 - 155]
@@ -93,7 +94,7 @@ class NooLite:
         """Save state on channel to scenario
         First channal is 0 """
         self._cmd = self._init_command
-        self._cmd[1] = 0x07       # "Turn power on" command
+        self._cmd[1] = 0x08       # record current state for scenario
         if self._set_ch(ch):
             return -2
         return self._send()
@@ -102,7 +103,7 @@ class NooLite:
         """Call saved scenario on channel
         First channal is 0 """
         self._cmd = self._init_command
-        self._cmd[1] = 0x07       # "Turn power on" command
+        self._cmd[1] = 0x07       # Load saved state command
         if self._set_ch(ch):
             return -2
         return self._send()
